#specifying transition probability matrix
tm<- matrix(c(0.7, 0.1, 0.2, 0.0, 0.6, 0.4, 0.5, 0.2, 0.3), nrow=3, ncol=3, 
byrow=TRUE)

#creating Markov chain object
library(markovchain)
mc<- new("markovchain", transitionMatrix=tm, states=c("1", "2", "3"))

#specifying total number of steps
nsteps<- 25

#specifying initial probability
p0<- c(1/3, 1/3, 1/3)

#specifying matrix containing states
MC.states<- matrix(NA, nrow=nsteps, ncol=2)

#specifying seed
set.seed(2443927)

#simulating trajectories
for (i in 1:2){
  state0<- sample(1:3, 1, prob=p0)
  MC.states[,i]<- rmarkovchain(n=nsteps-1, object=mc, t0=state0, include.t0=TRUE)
}

#plotting simulated trajectories
matplot(MC.states, type="l", lty=1, lwd=2, col=3:4, xaxt="n", yaxt="n", ylim=c(1,3), 
ylab="State", xlab="Step", panel.first=grid())

axis(side=1, at=c(1,5,10,15,20,25))
axis(side=2, at=c(1,2,3))

points(1:nsteps, MC.states[,1], pch=16, col=3)
points(1:nsteps, MC.states[,2], pch=16, col=4)


#####################################################
#simulating trajectories using user-defined function
#####################################################
#creating user-defined function

MC<- function(tm, p0, nsteps) {
  states<- numeric()
  states[1]<- sample(1:3, 1, prob=p0)
  
  for(t in 2:nsteps) {
    p<- tm[states[t-1],]  
    states[t]<- sample(1:3, 1, prob=p)
  }
  return(states)
}

#specifying seed
set.seed(2443927)

#simulating trajectories
MC.states2<- matrix(NA, nrow=nsteps, ncol=2)
for (j in 1:2)
  MC.states2[,j]<- MC(tm, p0, nsteps)

#plotting simulated trajectories
matplot(MC.states2, type="l", lty=1, lwd=2, col=3:4, xaxt="n", yaxt="n", 
ylim=c(1,3), xlab="Step", ylab="State", panel.first = grid())

axis(side=1, at=c(1,5,10,15,20,25))
axis(side=2, at=1:3)

points(1:nsteps, MC.states2[,1], pch=16, col=3)
points(1:nsteps, MC.states2[,2], pch=16, col=4)

#####################################################
#simulating probabilities
#####################################################
#specifying total number of steps
nsteps<- 15

#specifying matrix containing probabilities
probs<- matrix(NA, nrow=nsteps, ncol=3)

#computing probabilities pi_n 
probs[1,] <- p0
for(n in 2:nsteps) 
probs[n,]<- probs[n-1,]%*%tm

#plotting probabilities vs. step by state
matplot(probs, type="l", lty=1, lwd=2, col=2:4, ylim=c(0.2,0.5), 
xlab="Step", ylab="Probability", panel.first = grid())
legend("right", c("State 1", "State 2", "State 3"), lty=1, lwd=2, col=2:4)

probs
