#specifying the transition probability matrix
tm<- matrix(c(0.3,0.7,0,0,0,0,1,0,0,0,0,0,0.5,0,0,0,0,0.5,
0,0,0.6,0,0,0.4,0,0,0,0,0.1,0.9,0,0,0,0,0.7,0.3), nrow=6, 
ncol=6, byrow=TRUE)

#creating Markov chain object
library(markovchain)
mc<- new("markovchain", transitionMatrix=tm, 
states=c("1", "2", "3", "4", "5", "6"))

#specifying total number of steps
nsteps<- 20

#specifying initial probability
p0<- c(1/6, 1/6, 1/6, 1/6, 1/6, 1/6)

#specifying matrix containing states
MC.states<- matrix(NA, nrow=nsteps, ncol=3)

#specifying seed
set.seed(765881)

#simulating trajectories
for (i in 1:3){
  state0<- sample(1:6, 1, prob=p0)
  MC.states[,i]<- rmarkovchain(n=nsteps-1, object=mc, 
  t0=state0, include.t0=TRUE)
}

#plotting simulated trajectories
matplot(MC.states, type="l", lty=1, lwd=2, col=2:4, ylim=c(1,6), xaxt="n",
xlab="Step", ylab="State", panel.first=grid())

axis(side=1, at=c(1,5,10,15,20))

points(1:nsteps, MC.states[,1], pch=16, col=2)
points(1:nsteps, MC.states[,2], pch=16, col=3)
points(1:nsteps, MC.states[,3], pch=16, col=4)

###############################################
# Initial state 1
###############################################
#specifying total number of steps
nsteps<- 30

#specifying initial state distribution
p0<- c(1,0,0,0,0,0)

#specifying matrix containing probabilities
probs<- matrix(NA, nrow=nsteps, ncol=6)

#computing probabilities pi_n 
probs[1,] <- p0
for(n in 2:nsteps) 
  probs[n,]<- probs[n-1,]%*%tm

#plotting probabilities vs. step by state
matplot(probs, main="Initial State 1", type="l", lty=1, lwd=2, col=1:6,  
ylim=c(-0.05, 1.1), xlab="Step", ylab="Probability", panel.first=grid())

legend("topright", c("State 1", "State 2", "State 3", "State 4", "State 5", 
"State 6"), lty=1, lwd=2, col=1:6)

probs

###############################################
# Initial state 2
###############################################
#specifying total number of steps
nsteps<- 30

#specifying initial state distribution
p0<- c(0,1,0,0,0,0)

#specifying matrix containing probabilities
probs<- matrix(NA, nrow=nsteps, ncol=6)

#computing probabilities pi_n 
probs[1,] <- p0
for(n in 2:nsteps) 
  probs[n,]<- probs[n-1,]%*%tm

#plotting probabilities vs. step by state
matplot(probs, main="Initial State 2", type="l", lty=1, lwd=2, col=1:6,  
ylim=c(-0.05, 1.1), xlab="Step", ylab="Probability", panel.first=grid())

legend("topright", c("State 1", "State 2", "State 3", "State 4", "State 5", 
"State 6"), lty=1, lwd=2, col=1:6)

probs

###############################################
# Initial state 3
###############################################
#specifying total number of steps
nsteps<- 30

#specifying initial state distribution
p0<- c(0,0,1,0,0,0)

#specifying matrix containing probabilities
probs<- matrix(NA, nrow=nsteps, ncol=6)

#computing probabilities pi_n 
probs[1,] <- p0
for(n in 2:nsteps) 
  probs[n,]<- probs[n-1,]%*%tm

#plotting probabilities vs. step by state
matplot(probs, main="Initial State 3", type="l", lty=1, lwd=2, col=1:6,  
ylim=c(-0.05, 1.1), xlab="Step", ylab="Probability", panel.first=grid())

legend("topright", c("State 1", "State 2", "State 3", "State 4", "State 5", 
"State 6"), lty=1, lwd=2, col=1:6)

probs

###############################################
# Initial state 4
###############################################
#specifying total number of steps
nsteps<- 30

#specifying initial state distribution
p0<- c(0,0,0,1,0,0)

#specifying matrix containing probabilities
probs<- matrix(NA, nrow=nsteps, ncol=6)

#computing probabilities pi_n 
probs[1,] <- p0
for(n in 2:nsteps) 
  probs[n,]<- probs[n-1,]%*%tm

#plotting probabilities vs. step by state
matplot(probs, main="Initial State 4", type="l", lty=1, lwd=2, col=1:6,  
ylim=c(-0.05, 1.1), xlab="Step", ylab="Probability", panel.first=grid())

legend("topright", c("State 1", "State 2", "State 3", "State 4", "State 5", 
"State 6"), lty=1, lwd=2, col=1:6)

probs


###############################################
# Initial state 5
###############################################
#specifying total number of steps
nsteps<- 30

#specifying initial state distribution
p0<- c(0,0,0,0,1,0)

#specifying matrix containing probabilities
probs<- matrix(NA, nrow=nsteps, ncol=6)

#computing probabilities pi_n 
probs[1,] <- p0
for(n in 2:nsteps) 
  probs[n,]<- probs[n-1,]%*%tm

#plotting probabilities vs. step by state
matplot(probs, main="Initial State 5", type="l", lty=1, lwd=2, col=1:6,  
ylim=c(-0.05, 1.1), xlab="Step", ylab="Probability", panel.first=grid())

legend("topright", c("State 1", "State 2", "State 3", "State 4", "State 5", 
"State 6"), lty=1, lwd=2, col=1:6)

probs


###############################################
# Initial state 6
###############################################
#specifying total number of steps
nsteps<- 30

#specifying initial state distribution
p0<- c(0,0,0,0,0,1)

#specifying matrix containing probabilities
probs<- matrix(NA, nrow=nsteps, ncol=6)

#computing probabilities pi_n 
probs[1,] <- p0
for(n in 2:nsteps) 
  probs[n,]<- probs[n-1,]%*%tm

#plotting probabilities vs. step by state
matplot(probs, main="Initial State 6", type="l", lty=1, lwd=2, col=1:6,  
ylim=c(-0.05, 1.1), xlab="Step", ylab="Probability", panel.first=grid())

legend("topright", c("State 1","State 2","State 3","State 4","State 5",
"State 6"), lty=1, lwd=2, col=1:6)

probs
